@@ -98,7 +98,7 @@ QDateTime FlightPostProcessor::processFlightTime(QDateTime dt, const Flight &fli
         dt.setDate(flight.departureDay());
     }
 
-    if (dt.timeSpec() == Qt::TimeZone || codes.empty()) {
+    if ((dt.timeSpec() == Qt::TimeZone && dt.timeZone() != QTimeZone::utc()) || codes.empty()) {
         return dt;
     }
 
@@ -115,7 +115,7 @@ QDateTime FlightPostProcessor::processFlightTime(QDateTime dt, const Flight &fli
     if (dt.timeSpec() == Qt::OffsetFromUTC || dt.timeSpec() == Qt::LocalTime) {
         dt.setTimeSpec(Qt::TimeZone);
         dt.setTimeZone(tz);
-    } else if (dt.timeSpec() == Qt::UTC) {
+    } else if (dt.timeSpec() == Qt::UTC || (dt.timeSpec() == Qt::TimeZone && dt.timeZone() == QTimeZone::utc())) {
         dt = dt.toTimeZone(tz);
     }
 
