@@ -12,8 +12,8 @@
 
 #include <QExplicitlySharedDataPointer>
 #include <QMetaType>
+#include <QSize>
 
-class QSize;
 
 namespace KItinerary {
 
@@ -36,6 +36,8 @@ class KITINERARY_EXPORT Uic9183TicketLayoutField
     UIC_NUM_PROPERTY(size, 9 + m_offset, 4)
     UIC_STR_PROPERTY(text, 13 + m_offset, size())
 
+    Q_PROPERTY(bool isNull READ isNull STORED false)
+    Q_PROPERTY(KItinerary::Uic9183TicketLayoutField next READ next STORED false)
 public:
     Uic9183TicketLayoutField();
     /** Create a new U_TLAY field starting at @p offset in @p block.
@@ -63,7 +65,8 @@ class KITINERARY_EXPORT Uic9183TicketLayout
     Q_GADGET
     /** Ticket type (e.g. RCT2). */
     Q_PROPERTY(QString type READ type)
-
+    Q_PROPERTY(QSize size READ size)
+    Q_PROPERTY(KItinerary::Uic9183TicketLayoutField firstField READ firstField STORED false)
 public:
     Uic9183TicketLayout();
     /** Parse U_TLAY ticket layout block in @p data.
@@ -95,6 +98,9 @@ public:
      */
     Uic9183TicketLayoutField firstField() const;
 
+    /** All fields covering the given area. */
+    std::vector<Uic9183TicketLayoutField> fields(int row, int column, int width, int height) const;
+
     static constexpr const char RecordId[] = "U_TLAY";
 private:
     QExplicitlySharedDataPointer<Uic9183TicketLayoutPrivate> d;
